@@ -128,12 +128,8 @@ def chpath_inplace(filename, is_text_file, old, new):
 
 	f.close()
 	if modified:
-		if sys.hexversion >= 0x3030000:
-			orig_mtime = orig_stat.st_mtime_ns
-			os.utime(filename, ns=(orig_mtime, orig_mtime))
-		else:
-			orig_mtime = orig_stat[stat.ST_MTIME]
-			os.utime(filename, (orig_mtime, orig_mtime))
+		orig_mtime = orig_stat.st_mtime_ns
+		os.utime(filename, ns=(orig_mtime, orig_mtime))
 	return modified
 
 def chpath_inplace_symlink(filename, st, old, new):
