@@ -1,8 +1,6 @@
 # Copyright 1999-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-import functools
-import sys
 from itertools import chain
 import warnings
 
@@ -528,7 +526,7 @@ class Package(Task):
 		s += ")"
 		return s
 
-	class _use_class(object):
+	class _use_class:
 
 		__slots__ = ("enabled", "_expand", "_expand_hidden",
 			"_force", "_pkg", "_mask")
@@ -653,7 +651,7 @@ class Package(Task):
 
 		return use_str
 
-	class _iuse(object):
+	class _iuse:
 
 		__slots__ = ("__weakref__", "_iuse_implicit_match", "_pkg", "alias_mapping",
 			"all", "all_aliases", "enabled", "disabled", "tokens")
