@@ -16,7 +16,7 @@ portage.proxy.lazyimport.lazyimport(globals(),
 	'textwrap',
 	'_emerge.actions:load_emerge_config,run_action,' + \
 		'validate_ebuild_environment',
-	'_emerge.help:help@emerge_help',
+	'_emerge.help:emerge_help',
 	'_emerge.is_valid_package_atom:insert_category_into_atom'
 )
 from portage import os
@@ -99,7 +99,7 @@ def insert_optional_args(args):
 	this feature natively.
 	"""
 
-	class valid_integers(object):
+	class valid_integers:
 		def __contains__(self, s):
 			try:
 				return int(s) >= 0
@@ -108,7 +108,7 @@ def insert_optional_args(args):
 
 	valid_integers = valid_integers()
 
-	class valid_floats(object):
+	class valid_floats:
 		def __contains__(self, s):
 			try:
 				return float(s) >= 0
