@@ -10,7 +10,6 @@ __all__ = (
 
 import io
 import re
-import sys
 
 from portage import os
 from portage import _encodings, _unicode_encode
@@ -28,7 +27,7 @@ from _emerge.Blocker import Blocker
 from _emerge.Package import Package
 
 
-class _RepoDisplay(object):
+class _RepoDisplay:
 	def __init__(self, roots):
 		self._shown_repos = {}
 		self._unknown_repo = False
@@ -77,7 +76,7 @@ class _RepoDisplay(object):
 		return "".join(output)
 
 
-class _PackageCounters(object):
+class _PackageCounters:
 
 	def __init__(self):
 		self.upgrades   = 0
@@ -155,7 +154,7 @@ class _PackageCounters(object):
 		return "".join(myoutput)
 
 
-class _DisplayConfig(object):
+class _DisplayConfig:
 
 	def __init__(self, depgraph, mylist, favorites, verbosity):
 		frozen_config = depgraph._frozen_config
@@ -470,7 +469,7 @@ def _prune_tree_display(display_list):
 				del display_list[i]
 
 
-def _calc_changelog(ebuildpath,current,next):
+def _calc_changelog(ebuildpath,current,next): # pylint: disable=redefined-builtin
 	if ebuildpath == None or not os.path.exists(ebuildpath):
 		return []
 	current = '-'.join(catpkgsplit(current)[1:])
@@ -585,7 +584,7 @@ def _find_changelog_tags(changelog):
 		_strip_header_comments(changelog[release_end:].splitlines())))
 	return divs
 
-class PkgInfo(object):
+class PkgInfo:
 	"""Simple class to hold instance attributes for current
 	information about the pkg being printed.
 	"""
