@@ -5,7 +5,6 @@
 # the whole _selinux module itself will be wrapped.
 import os
 import shutil
-import sys
 import warnings
 
 try:
@@ -105,7 +104,7 @@ def setfscreate(ctx="\n"):
 		raise OSError(
 			_("setfscreate: Failed setting fs create context \"%s\".") % ctx)
 
-class spawn_wrapper(object):
+class spawn_wrapper:
 	"""
 	Create a wrapper function for the given spawn function. When the wrapper
 	is called, it will adjust the arguments such that setexec() to be called
