@@ -5,12 +5,11 @@
 from portage.cache import cache_errors
 from portage.cache.cache_errors import InvalidRestriction
 from portage.cache.mappings import ProtectedDict
-import sys
 import warnings
 import operator
 
 
-class database(object):
+class database:
 	# this is for metadata/cache transfer.
 	# basically flags the cache needs be updated when transfered cache to cache.
 	# leave this.
