@@ -44,7 +44,6 @@ import errno
 import io
 import stat
 import subprocess
-import sys
 import tempfile
 import textwrap
 import time
@@ -327,7 +326,7 @@ class bindbapi(fakedbapi):
 		return filesdict
 
 
-class binarytree(object):
+class binarytree:
 	"this tree scans for a list of all packages available in PKGDIR"
 	def __init__(self, _unused=DeprecationWarning, pkgdir=None,
 		virtual=DeprecationWarning, settings=None):
