@@ -39,7 +39,6 @@ from portage.util.futures.iter_completed import iter_gather
 from _emerge.EbuildMetadataPhase import EbuildMetadataPhase
 
 import os as _os
-import sys
 import traceback
 import warnings
 import errno
@@ -98,7 +97,7 @@ class _dummy_list(list):
 			pass
 
 
-class _better_cache(object):
+class _better_cache:
 
 	"""
 	The purpose of better_cache is to locate catpkgs in repositories using ``os.listdir()`` as much as possible, which
@@ -878,7 +877,7 @@ class portdbapi(dbapi):
 				filesdict[myfile] = int(checksums[myfile]["size"])
 		return filesdict
 
-	def fetch_check(self, mypkg, useflags=None, mysettings=None, all=False, myrepo=None):
+	def fetch_check(self, mypkg, useflags=None, mysettings=None, all=False, myrepo=None): # pylint: disable=redefined-builtin
 		"""
 		TODO: account for PORTAGE_RO_DISTDIRS
 		"""
@@ -1311,7 +1310,7 @@ class portdbapi(dbapi):
 
 		return True
 
-class portagetree(object):
+class portagetree:
 	def __init__(self, root=DeprecationWarning, virtual=DeprecationWarning,
 		settings=None):
 		"""
