@@ -1,11 +1,10 @@
 # Copyright 2015-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-import sys
 
 from portage import _encodings, _unicode_encode
 
-class SonameAtom(object):
+class SonameAtom:
 
 	__slots__ = ("multilib_category", "soname", "_hash_key",
 		"_hash_value")
