@@ -97,7 +97,7 @@ def diff_mixed(func, file1, file2):
 		if tempdir is not None:
 			shutil.rmtree(tempdir)
 
-class diff_mixed_wrapper(object):
+class diff_mixed_wrapper:
 
 	def __init__(self, f, *args):
 		self._func = f
