@@ -1,9 +1,7 @@
 # Copyright 2014-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-import logging
 import os
-import sys
 
 import portage
 portage._internal_caller = True
@@ -33,7 +31,7 @@ portage.proxy.lazyimport.lazyimport(globals(),
 warn = create_color_func("WARN")
 
 
-class SyncRepos(object):
+class SyncRepos:
 
 	short_desc = "Check repos.conf settings and/or sync repositories"
 
