@@ -6,7 +6,6 @@ import io
 import logging
 import re
 import stat
-import sys
 import warnings
 
 import portage
@@ -62,8 +61,8 @@ def guessManifestFileType(filename):
 		return "DIST"
 
 def guessThinManifestFileType(filename):
-	type = guessManifestFileType(filename)
-	if type != "DIST":
+	filetype = guessManifestFileType(filename)
+	if filetype != "DIST":
 		return None
 	return "DIST"
 
@@ -80,7 +79,7 @@ def parseManifest2(line):
 			name=match.group(2), hashes=hashes)
 	return myentry
 
-class ManifestEntry(object):
+class ManifestEntry:
 	__slots__ = ("type", "name", "hashes")
 	def __init__(self, **kwargs):
 		for k, v in kwargs.items():
@@ -108,7 +107,7 @@ class Manifest2Entry(ManifestEntry):
 		return not self.__eq__(other)
 
 
-class Manifest(object):
+class Manifest:
 	parsers = (parseManifest2,)
 	def __init__(self, pkgdir, distdir=None, fetchlist_dict=None,
 		manifest1_compat=DeprecationWarning, from_scratch=False, thin=False,
