@@ -4,7 +4,6 @@
 import io
 import logging
 import warnings
-import sys
 import re
 
 import portage
@@ -66,7 +65,7 @@ def _find_invalid_path_char(path, pos=0, endpos=None):
 
 	return -1
 
-class RepoConfig(object):
+class RepoConfig:
 	"""Stores config of one repository"""
 
 	__slots__ = (
@@ -258,10 +257,10 @@ class RepoConfig(object):
 		self.module_specific_options = {}
 
 		# Not implemented.
-		format = repo_opts.get('format')
-		if format is not None:
-			format = format.strip()
-		self.format = format
+		repo_format = repo_opts.get('format')
+		if repo_format is not None:
+			repo_format = repo_format.strip()
+		self.format = repo_format
 
 		self.user_location = None
 		location = repo_opts.get('location')
@@ -531,7 +530,7 @@ class RepoConfig(object):
 		return "%s" % (d,)
 
 
-class RepoConfigLoader(object):
+class RepoConfigLoader:
 	"""Loads and store config of several repositories, loaded from PORTDIR_OVERLAY or repos.conf"""
 
 	@staticmethod
