@@ -4,7 +4,6 @@
 import bz2
 from itertools import permutations
 import fnmatch
-import sys
 import tempfile
 import portage
 from portage import os
@@ -35,7 +34,7 @@ except ImportError:
 	cnf_path_repoman = None
 
 
-class ResolverPlayground(object):
+class ResolverPlayground:
 	"""
 	This class helps to create the necessary files on disk and
 	the needed settings instances, etc. for the resolver to do
@@ -641,7 +640,7 @@ class ResolverPlayground(object):
 		else:
 			shutil.rmtree(self.eroot)
 
-class ResolverPlaygroundTestCase(object):
+class ResolverPlaygroundTestCase:
 
 	def __init__(self, request, **kwargs):
 		self.all_permutations = kwargs.pop("all_permutations", False)
@@ -819,7 +818,7 @@ def _mergelist_str(x, depgraph):
 	return mergelist_str
 
 
-class ResolverPlaygroundResult(object):
+class ResolverPlaygroundResult:
 
 	checks = (
 		"success", "mergelist", "use_changes", "license_changes",
@@ -913,7 +912,7 @@ class ResolverPlaygroundResult(object):
 		if required_use_unsatisfied:
 			self.required_use_unsatisfied = set(required_use_unsatisfied)
 
-class ResolverPlaygroundDepcleanResult(object):
+class ResolverPlaygroundDepcleanResult:
 
 	checks = (
 		"success", "cleanlist", "ordered", "req_pkg_count",
