@@ -8,7 +8,6 @@ try:
 except ImportError:
 	import dummy_threading as threading
 
-import sys
 import time
 
 from portage.tests import TestCase
@@ -23,7 +22,7 @@ class SucceedLaterException(Exception):
 	pass
 
 
-class SucceedLater(object):
+class SucceedLater:
 	"""
 	A callable object that succeeds some duration of time has passed.
 	"""
@@ -48,7 +47,7 @@ class SucceedNeverException(Exception):
 	pass
 
 
-class SucceedNever(object):
+class SucceedNever:
 	"""
 	A callable object that never succeeds.
 	"""
@@ -60,7 +59,7 @@ class SucceedNever(object):
 		return result
 
 
-class HangForever(object):
+class HangForever:
 	"""
 	A callable object that sleeps forever.
 	"""
