@@ -6,7 +6,6 @@ import errno
 import itertools
 import logging
 import subprocess
-import sys
 
 import portage
 from portage import _encodings
@@ -51,7 +50,7 @@ _approx_multilib_categories = {
 	"X86_64":        "x86_64",
 }
 
-class LinkageMapELF(object):
+class LinkageMapELF:
 
 	"""Models dynamic linker dependencies."""
 
@@ -59,7 +58,7 @@ class LinkageMapELF(object):
 	_soname_map_class = slot_dict_class(
 		("consumers", "providers"), prefix="")
 
-	class _obj_properties_class(object):
+	class _obj_properties_class:
 
 		__slots__ = ("arch", "needed", "runpaths", "soname", "alt_paths",
 			"owner",)
@@ -102,7 +101,7 @@ class LinkageMapELF(object):
 			self._obj_key_cache[path] = key
 		return key
 
-	class _ObjectKey(object):
+	class _ObjectKey:
 
 		"""Helper class used as _obj_properties keys for objects."""
 
@@ -485,7 +484,7 @@ class LinkageMapELF(object):
 
 		os = _os_merge
 
-		class _LibraryCache(object):
+		class _LibraryCache:
 
 			"""
 			Caches properties associated with paths.
